Struct themelio_structs::CoinDataHeight
source · [−]pub struct CoinDataHeight {
pub coin_data: CoinData,
pub height: BlockHeight,
}Expand description
A CoinData but coupled with a block height. This is what actually gets stored in the global state, allowing constraints and the validity-checking algorithm to easily access the age of a coin.
Fields
coin_data: CoinDataheight: BlockHeightTrait Implementations
sourceimpl Clone for CoinDataHeight
impl Clone for CoinDataHeight
sourcefn clone(&self) -> CoinDataHeight
fn clone(&self) -> CoinDataHeight
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CoinDataHeight
impl Debug for CoinDataHeight
sourceimpl<'de> Deserialize<'de> for CoinDataHeight
impl<'de> Deserialize<'de> for CoinDataHeight
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for CoinDataHeight
impl Hash for CoinDataHeight
sourceimpl PartialEq<CoinDataHeight> for CoinDataHeight
impl PartialEq<CoinDataHeight> for CoinDataHeight
sourcefn eq(&self, other: &CoinDataHeight) -> bool
fn eq(&self, other: &CoinDataHeight) -> bool
sourceimpl Serialize for CoinDataHeight
impl Serialize for CoinDataHeight
impl Eq for CoinDataHeight
impl StructuralEq for CoinDataHeight
impl StructuralPartialEq for CoinDataHeight