pub struct PoolState {
    pub lefts: u128,
    pub rights: u128,
    pub price_accum: u128,
    pub liqs: u128,
}
The internal status of a Melswap pool. Notably, this does not identify which pool this is, or even what tokens are the “lefts” and “rights”.

Fields

lefts: u128

How many “left-hand” tokens (the token with the lexicographically smaller Denom) are there in the pool, in microunits.

rights: u128

How many “right-hand” tokens are there in the pool.

price_accum: u128

A Uniswap-like TWAP of the price. TODO document this more

liqs: u128

How many liquidity tokens have been issued

Implementations

Creates a new empty pool.

Executes a swap.

Deposits a set amount into the state, returning how many liquidity tokens were created.

Redeems a set amount of liquidity tokens, returning lefts and rights.

Returns the implied price as lefts per right.

Returns the liquidity constant of the system.