Struct themelio_structs::PoolState
source · [−]Expand description
The internal status of a Melswap pool. Notably, this does not identify which pool this is, or even what tokens are the “lefts” and “rights”.
Fields
lefts: u128How many “left-hand” tokens (the token with the lexicographically smaller Denom) are there in the pool, in microunits.
rights: u128How many “right-hand” tokens are there in the pool.
price_accum: u128A Uniswap-like TWAP of the price. TODO document this more
liqs: u128How many liquidity tokens have been issued
Implementations
sourceimpl PoolState
impl PoolState
sourcepub fn deposit(&mut self, lefts: u128, rights: u128) -> u128
pub fn deposit(&mut self, lefts: u128, rights: u128) -> u128
Deposits a set amount into the state, returning how many liquidity tokens were created.
sourcepub fn withdraw(&mut self, liqs: u128) -> (u128, u128)
pub fn withdraw(&mut self, liqs: u128) -> (u128, u128)
Redeems a set amount of liquidity tokens, returning lefts and rights.
sourcepub fn implied_price(&self) -> BigRational
pub fn implied_price(&self) -> BigRational
Returns the implied price as lefts per right.
sourcepub fn liq_constant(&self) -> u128
pub fn liq_constant(&self) -> u128
Returns the liquidity constant of the system.