Struct themelio_structs::PoolState
source · [−]Fields
lefts: u128rights: u128Implementations
Deposits a set amount into the state, returning how many liquidity tokens were created.
Redeems a set amount of liquidity tokens, returning lefts and rights.
Returns the implied price as lefts per right.
Returns the liquidity constant of the system.