Struct themelio_structs::StakeDoc
source · [−]pub struct StakeDoc {
pub pubkey: Ed25519PK,
pub e_start: u64,
pub e_post_end: u64,
pub syms_staked: CoinValue,
}Expand description
StakeDoc is a stake document. It encapsulates all the information needed to verify consensus proofs.
Fields
pubkey: Ed25519PKPublic key.
e_start: u64Starting epoch.
e_post_end: u64Ending epoch. This is the epoch after the last epoch in which the syms are effective.
syms_staked: CoinValueNumber of syms staked.