pub struct Transaction {
    pub kind: TxKind,
    pub inputs: Vec<CoinID>,
    pub outputs: Vec<CoinData>,
    pub fee: CoinValue,
    pub covenants: Vec<Vec<u8>>,
    pub data: Vec<u8>,
    pub sigs: Vec<Vec<u8>>,
}
Transaction represents an individual, serializable Themelio transaction.

Fields

kind: TxKindinputs: Vec<CoinID>outputs: Vec<CoinData>fee: CoinValuecovenants: Vec<Vec<u8>>data: Vec<u8>sigs: Vec<Vec<u8>>

Implementations

An empty transaction with kind Normal, no inputs, no fees, etc.

Creates a new transaction with the given kind, no inputs, no outputs, no nothing.

Replaces the kind of the transaction

Replaces the inputs of the transaction

Add an input

Replaces the outputs of the transaction

Add an output

Replaces the fee of the transaction

Replaces the scripts of the transaction

Add a script to the transaction

Replaces the scripts of the transaction

Replaces the scripts of the transaction

Checks whether or not the transaction is well formed, respecting coin size bounds and such. Does not fully validate the transaction.

hash_nosigs returns the hash of the transaction with a zeroed-out signature field. This is what signatures are computed against.

sign_ed25519 consumes the transaction, appends an ed25519 signature, and returns it.

total_outputs returns a HashMap mapping each type of coin to its total value. Fees will be included in the Mel cointype.

scripts_as_map returns a HashMap mapping the hash of each script in the transaction to the script itself.

Returns the minimum fee of the transaction at a given fee multiplier, with a given “ballast”.

Returns the weight of the transaction, given a function that maps a covenant to its weight.

Convenience function that constructs a CoinID that points to a certain output of this transaction. Panics if the index is out of bounds.